/**
  * @description 输入下拉的交互组件 解决离散不可枚举的标签
  */
import React from 'react';
import Select from 'antd/lib/select/index.js'; 
import SelectStyle from 'antd/lib/select/style/index.js'; 
const Option = Select.Option;
import Ajax from './ajax.js';
import url from './url.js';
import './selectlabel.less';
export default class SelectLabel extends React.Component {
	constructor (props) {
		super(props);	
		this.state = {
			data: null,
			cls: '',
			multiple: props.option.configInfo.showType != 'single',
			value: null
		};
	}
	onChange(value) {
		console.log('change');
		if (value) {
			this.setValue(value);
		} else {
			this.setValue("null");
		}
		//this.props.filter();
	 }
	setValue(value){
		this.radio = value;
	}
	getValue () {
		let option = this.props.option;
		let value = this.radio;
		if (!value) {
			return;	
		}
		let params = {
			"childrenRules": [],
			"relForChildren": "AND",
			"relForSelf": "AND",
			"relForSelfAndChildren": "AND",
			"selfItems": [{
				"code": option.code,
				"id": option.id,
				"name": option.name,
				"tableCode": this.props.tableCode
			}]
		};
		let tmp = params.selfItems[0];
		if (value instanceof Array) {
			//数组
			tmp.value = {
				"@class": "com.alipay.antdac.profile.common.service.facade.model.DiscretePropertyValue",
				"valueOperator": "IN",
				"values": value,
				"valueType": "STRING"
			};	
		} else {
			//单值	
			tmp.value = {
				"@class": "com.alipay.antdac.profile.common.service.facade.model.NormalPropertyValue",
				"value": value,
				"valueOperator": "EQ",
				"valueType": "STRING"
			};	
		}
		return params;
	}
	onSelect(value) {
		if (this.state.multiple) {
			//复选的时候	
			let tmpValue = this.state.value || [];
			tmpValue.push(value);
			this.setValue(tmpValue);
		} else {
			this.setValue (value);
		}
		this.props.filter();
	}
	//获取对应数据
	query (query)  {
		if (!query) {
			this.setState({
				data: []			
			});	
			return;
		}
		if (!this.state.multiple) {
			//单选的时候输入即更新对应的值	
			this.state.value = query;
		}
		let reg = new RegExp(query);
		let option = this.props.option;
		let params = {
			url: url('/profile/api/crowd/tag/getTagValue.json?tagId=' + option.id + '&tagValue=' + query),	
			success: function (data) {
				let list = [];
				let values = data.values;
				//过滤当前的值
				for (let i = 0; i < values.length; i++) {
					let cur = values[i];	
					if (reg.test(cur.name)) {
						list.push(cur);	
					}
				}
				if (list.length == 0) {
					list.push({
						label: query,
						value: query,
						cls: 'not-found'
					});	
				}
				this.setState({
					data: list			
				});
			}.bind(this)
		};	
		Ajax(params);
	}
	render () {
		let style = {width: '100%'};
		let option = this.props.option;
		let data = this.state.data;
		let options = null;
		let multiple = false;
		if (option.configInfo.showType == 'single') {
			multiple = false;	
		} else {
			multiple = true;	
		}
		if (data) {
			options = data.map(function (item) {
				let cls = item.cls || '';
				return (
					<Option className={cls} value={item.value} key={item.value}>{item.name || item.value}</Option>			
				);		
			});
		}
		if (multiple) {
			//多选
			return (
				<Select ref={(c)=>this.select=c}
					multiple={multiple}
					optionFilterProp="children"
					optionLabelProp="children"
					style={style}
					onSearch={this.query.bind(this)}
					onSelect={this.onSelect.bind(this)}
					placeholder={option.placeholder}
					 onChange={this.onChange.bind(this)}
					 >
					{options}
				</Select>
			);
		} else {
			//单选
			return (
				<Select ref={(c)=>this.select=c}
					combobox
					optionFilterProp="children"
					optionLabelProp="children"
					style={style}
					onSearch={this.query.bind(this)}
					onSelect={this.onSelect.bind(this)}
					placeholder={option.placeholder}
					 onChange={this.onChange.bind(this)}
					 >
					{options}
				</Select>
			);
		}
	}
}
